A class that represents an affine combination of variables.
vars:Object of class "character"-- the variables included in this affine expression
coefs:Object of class "numeric", the scalar coefficients matching the the vars
offset:Object of class "numeric", which indicates the scalar that offsets this affine expression from a linear expression.