A class that holds all the necessary data to build a linear programming model.
| ... | Additional arguments to pass to the ROI_solve method. |
|---|
senseShould the objective be minimized ("min") or maximized ("max")?
solnAn object of class "OP_solution" that contains information about the problem solution.
.__obj(Internal use only) The objective function of the model.
.__constraints(Internal use only) A list of constraints of the model.
.__variables(Internal use only) An array of the variables declared in the model.