An abstract class that represents arrays or variables that conform to algebraic rules.
name:Object of class "character"-- the name of the variable in the user's scope.
bounds:Object of class "numeric", which defines the lower and upper bounds of the variable's domain.
integer:Object of class "character", which defines if the variable is a "Real", "Integer", or "Binary"
value:Object of class "numeric", the value of the variable at the model's optimum.